@@ -1114,6 +1114,8 @@ sub mouse_button1($$$$;)
     my $x     = shift;
     my $y     = shift;
 
+    return unless $this->{-focusable};
+
     # TODO: make this possible for multi line widgets.
     if ($this->{-singleline})
     {
@@ -1540,6 +1542,18 @@ This method can be used to set the B<-onchange> event handler
 This method can be used to change the password property.  The password 
 character will be set to $char, or turned off in $char is undef.
 
+=item * B<toggle_showhardreturns>
+
+Toggles the -showhardreturns option.
+
+=item * B<toggle_showoverflow>
+
+Toggles the -showoverflow option.
+
+=item * B<toggle_wrapping>
+
+Toggles the -wrapping option.
+
 =back
 
 
